#ifndef CAMLOAD_LIB_OBJC_H
#define CAMLOAD_LIB_OBJC_H
//
//  CamLoadLib_ObjC.h
//  CamLoadLib_ObjC
//
//  Created by Laurie Hufford on 6/15/10.
//  Copyright 2010 PhaseOne. All rights reserved.
//
#import <Cocoa/Cocoa.h>

#import "CamLoadLibEnums.h"

//device property keys
extern NSString* const kDeviceIDKey;
extern NSString* const kDeviceTypeKey;
extern NSString* const kDeviceNameKey;
extern NSString* const kDeviceManufacturerKey;
//model property keys
extern NSString* const kModelIndexKey;
extern NSString* const kModelNameKey;
extern NSString* const kModelTypeKey;
extern NSString* const kModelSerialKey;
extern NSString* const kModelHWConfigKey;
extern NSString* const kModelIDKey;
extern NSString* const kModelCapCountKey;

extern NSString* const kModelComponentNamesKey;
extern NSString* const kModelFirmwareVersionsKey;
extern NSString* const kModelMountKey;
extern NSString* const kModelCalibDateKey;

extern NSString* const kCalibFileSerialKey;
extern NSString* const kCalibFileDateKey;

//notification keys
extern NSString* const kNotificationDeviceConnectedKey;
extern NSString* const kNotificationDeviceDisconnectedKey;
extern NSString* const kNotificationUpdateProgressKey;
extern NSString* const kNotificationUpdateSuccessfulKey;
extern NSString* const kNotificationUpdateFailureKey;
extern NSString* const kNotificationUpdateStoppedKey;
extern NSString* const kNotificationUpdateStatusUpdatedKey;
extern NSString* const kNotificationUpdateErrorMessageKey;
extern NSString* const kNotificationUpdateStartFailedKey;
extern NSString* const kNotificationUpdateStartedKey;
//event data keys
extern NSString* const kEventProgressInfoKey;
extern NSString* const kEventMessageKey;


typedef NSUInteger DeviceId;
typedef NSUInteger ModelIndex;
typedef NSUInteger ComponentIndex;

@interface CamLoadLib_ObjC : NSObject { 
	void* _privateA; void* _privateB; id _privateC;
	
}
+(NSArray*) ComponentNamesArray;

-(NSDictionary*) GetDeviceProperties:(DeviceId)deviceID;
-(void)	RefreshDevicesList;
-(NSArray*) GetConnectedDeviceIDs;

 
-(void)	UpdateFirmware: (NSString*)filePath 
			  deviceID: (DeviceId)deviceID
			 modelName: (NSString*)modelName
		 componentName: (NSString*)componentName;
/*
-(void)	UpdateFirmware: (NSString*)filePath 
			  deviceID: (DeviceId)deviceID
			modelIndex: (ModelIndex)modelIndex
		componentIndex: (ComponentIndex)componentIndex;
*/

-(NSUInteger) GetModelCount: (DeviceId)deviceID;

-(NSDictionary*) GetModelProperties: (DeviceId)deviceID
						 modelIndex: (ModelIndex)modelIndex;
-(NSDictionary*) GetModelProperties: (DeviceId)deviceID
						  modelName: (NSString*)modelName;

-(NSDictionary*) GetComponentVersions: (DeviceId)deviceID
						   modelIndex: (ModelIndex)modelIndex
						 userFriendly: (BOOL)userFriendly;

-(NSArray*) GetComponentNames: (DeviceId)deviceID 
					modelName: (NSString*)modelName;
-(NSArray*) GetComponentNames: (DeviceId)deviceID 
				   modelIndex: (ModelIndex)modelIndex;

-(NSArray*) GetFirmwareVersions: (DeviceId)deviceID
					  modelName: (NSString*)modelName
				   userFriendly: (BOOL)userFriendly;
-(NSArray*) GetFirmwareVersions: (DeviceId)deviceID
					 modelIndex: (ModelIndex)modelIndex
				   userFriendly: (BOOL)userFriendly;



-(BOOL) DoesDeviceSupportCalibrationFiles: (DeviceId)deviceID
							   modelIndex: (ModelIndex)modelIndex;

-(NSDictionary*) GetCalibrationFileInfo:(NSString*)calibFilePath deviceID: (DeviceId)deviceID;

-(BOOL) BackupCalibrationFileTo: (NSString*)backupPath
					   deviceID: (DeviceId)deviceID
					 modelIndex: (ModelIndex)modelIndex;

-(void) UploadCalibrationFile: (NSString*)calibFilePath
					 deviceID: (DeviceId)deviceID
				   modelIndex: (ModelIndex)modelIndex;


/*
-(NSComparisonResult) CompareFWComponentVersion: (DeviceId)deviceID
									  modelName: (NSString*)modelName
								  componentName: (NSString*)componentName
								  againstString: (NSString*)versionString;
-(NSComparisonResult) CompareFWComponentVersion: (DeviceId)deviceID
									 modelIndex: (ModelIndex)modelIndex
								 componentIndex: (ComponentIndex)componentIndex
								  againstString: (NSString*)versionString;

-(NSString*) FormatToUserFriendlyFWComponentVersion: (DeviceId)deviceID
										  modelName: (NSString*)modelName
									  componentName: (NSString*)componentName
									  versionString: (NSString*)versionString;
-(NSString*) FormatToUserFriendlyFWComponentVersion: (DeviceId)deviceID
										 modelIndex: (ModelIndex)modelIndex
									 componentIndex: (ComponentIndex)componentIndex
									  versionString: (NSString*)versionString;
*/
@end

#endif //CAMLOAD_LIB_OBJC_H
